package WebGUI::i18n::German::Account_Inbox;
use utf8;
our $I18N = {
  'All users' => {
    'lastUpdated' => '1243114221',
    'message' => 'Alle Benutzer'
  },
  'accept button label' => {
    'lastUpdated' => '1235675859',
    'message' => 'Annehmen'
  },
  'already a member' => {
    'lastUpdated' => '1231216905',
    'message' => 'Die von Ihnen eingetragene Adresse ist hier bereits für %s registriert'
  },
  'back label' => {
    'lastUpdated' => '1231216923',
    'message' => 'Zurück zum Posteingang'
  },
  'blocked error' => {
    'lastUpdated' => '1231216958',
    'message' => 'Dieser Benutzer wünscht keine private Nachrichten zu empfangen'
  },
  'canSendMessages' => {
    'lastUpdated' => '1235679070',
    'message' => 'Eine Variable die wahr ist, falls der Benutzer Freunde hat, denen er Mitteilungen schicken kann.'
  },
  'cancel label' => {
    'lastUpdated' => '1231216968',
    'message' => 'Abbrechen'
  },
  'common account variables' => {
    'lastUpdated' => '1232485773',
    'message' => 'Allgemeines Konto, Posteingang'
  },
  'compose message label' => {
    'lastUpdated' => '1240172740',
    'message' => 'Neue Nachricht erstellen'
  },
  'currently invited' => {
    'lastUpdated' => '1245619563',
    'message' => 'Die Emailadresse, die Sie eingegeben haben, %s, hat eine offene Einladung'
  },
  'date label' => {
    'lastUpdated' => '1231216994',
    'message' => 'Datum'
  },
  'dateStamp' => {
    'lastUpdated' => '1235680387',
    'message' => 'Das Datum, an dem die Mitteilung versendet wurde (Epoch-Format).'
  },
  'dateStamp_formatted' => {
    'lastUpdated' => '1235680447',
    'message' => 'Das Datum, an dem die Mitteilung versendet wurde; entsprechend den Einstellungen des Benutzers formatiert.'
  },
  'dateStamp_url' => {
    'lastUpdated' => '1235680637',
    'message' => 'Der URL, um die Mitteilungen im Posteingang nach dem Versanddatum zu sortieren.'
  },
  'delete label' => {
    'lastUpdated' => '1231217003',
    'message' => 'Löschen'
  },
  'deny button label' => {
    'lastUpdated' => '1231217012',
    'message' => 'Ablehnen'
  },
  'error label' => {
    'lastUpdated' => '1231217022',
    'message' => 'Fehler'
  },
  'form_footer' => {
    'lastUpdated' => '1235681550',
    'message' => 'HTML-Code zum Abschluss des Formulars auf dieser Seite.'
  },
  'form_header' => {
    'lastUpdated' => '1235681536',
    'message' => 'HTML-Code zum Beginn des Formulars auf dieser Seite.'
  },
  'from' => {
    'lastUpdated' => '1235681566',
    'message' => 'Der Name des Absenders.'
  },
  'from label' => {
    'lastUpdated' => '1231217029',
    'message' => 'Von'
  },
  'from_id' => {
    'lastUpdated' => '1235681607',
    'message' => 'Die Benutzer-Id des Absenders.'
  },
  'from_url' => {
    'lastUpdated' => '1235681669',
    'message' => 'Der URL zur Anzeige des Benutzer-Profils des Absenders.'
  },
  'has_messages' => {
    'lastUpdated' => '1235681694',
    'message' => 'Eine Variable die wahr ist, falls der Benutzer Mitteilungen im Posteingang hat.'
  },
  'inbox copy sender hoverHelp' => {
    'lastUpdated' => '1243114357',
    'message' => 'Wenn "ja", werden Benutzer eine Kopie der Nachrichten bekommen, die sie über die Inbox versenden.'
  },
  'inbox copy sender label' => {
    'lastUpdated' => '1243114433',
    'message' => 'Kopie an Absender?'
  },
  'inbox error message template hoverHelp' => {
    'lastUpdated' => '1232889358',
    'message' => 'Die Vorlage zur Anzeige von Fehlermeldungen.'
  },
  'inbox error message template label' => {
    'lastUpdated' => '1233943093',
    'message' => 'Vorlage Fehlermeldungen'
  },
  'inbox layout template hoverHelp' => {
    'lastUpdated' => '1232889702',
    'message' => 'Die Vorlage zur Anzeige des Posteingangs sowie einer Auflistung der anderen verfügbaren Konto-Erweiterungen.'
  },
  'inbox layout template label' => {
    'lastUpdated' => '1233942273',
    'message' => 'Layout'
  },
  'inbox manage invitations template hoverHelp' => {
    'lastUpdated' => '1232889769',
    'message' => 'Die Vorlage für die Verwaltung von Einladungen.'
  },
  'inbox manage invitations template label' => {
    'lastUpdated' => '1233943111',
    'message' => 'Vorlage Einladungsverwaltung'
  },
  'inbox message confirm template hoverHelp' => {
    'lastUpdated' => '1233553696',
    'message' => 'Die Vorlage zur Anzeige einer Bestätigung, dass eine Nachricht versendet wurde.'
  },
  'inbox message confirm template label' => {
    'lastUpdated' => '1233943125',
    'message' => 'Vorlage Mitteilungsbestätigungen'
  },
  'inbox notification' => {
    'lastUpdated' => '1243496397',
    'message' => 'Sie haben eine neue Nachricht in Ihrem Postfach'
  },
  'inbox notification template' => {
    'lastUpdated' => '1243496425',
    'message' => 'Vorlage für neue Nachricht'
  },
  'inbox notification template help' => {
    'lastUpdated' => '1243496435',
    'message' => 'Wählen Sie eine Vorlage für "Neue Nachricht in Postfach"'
  },
  'inbox notifications subject' => {
    'lastUpdated' => '1250929947',
    'message' => 'Betreff Mitteilung Posteingang'
  },
  'inbox notifications subject help' => {
    'lastUpdated' => '1250930007',
    'message' => 'Der Betreff für Mitteilungen bezüglich neue Mails im Postfach'
  },
  'inbox rich editor description' => {
    'lastUpdated' => '1233553797',
    'message' => 'Der Editor, welcher für das Verfassen von Nachrichten verwendet werden soll.'
  },
  'inbox rich editor label' => {
    'lastUpdated' => '1232885931',
    'message' => 'Editor für Posteingang'
  },
  'inbox send message template hoverHelp' => {
    'lastUpdated' => '1233553813',
    'message' => 'Die Vorlage für den Versand von Nachrichten.'
  },
  'inbox send message template label' => {
    'lastUpdated' => '1233943164',
    'message' => 'Vorlage Mitteilungsversand'
  },
  'inbox sms notification' => {
    'lastUpdated' => '1250930048',
    'message' => 'Sie haben eine neue Mail in Ihrem Postfach'
  },
  'inbox sms notification template' => {
    'lastUpdated' => '1250930145',
    'message' => 'Vorlage Neue SMS-Mitteilung im Postfach '
  },
  'inbox sms notification template help' => {
    'lastUpdated' => '1250930219',
    'message' => 'Wählen Sie eine Vorlage für SMS-Mitteilungen bzgl. Posteingang'
  },
  'inbox style template hoverHelp' => {
    'lastUpdated' => '1233553843',
    'message' => 'Der Stilvorlage für den Posteingang.'
  },
  'inbox style template label' => {
    'lastUpdated' => '1233942296',
    'message' => 'Stilvorlage'
  },
  'inbox view invitation template hoverHelp' => {
    'lastUpdated' => '1233553859',
    'message' => 'Die Vorlage zur Anzeige von Einladungen.'
  },
  'inbox view invitation template label' => {
    'lastUpdated' => '1233943133',
    'message' => 'Vorlage Einladungsanzeige'
  },
  'inbox view message template hoverHelp' => {
    'lastUpdated' => '1233553881',
    'message' => 'Die Vorlage zur Anzeige von Nachrichten im Posteingang.'
  },
  'inbox view message template label' => {
    'lastUpdated' => '1233943184',
    'message' => 'Vorlage Mitteilungsanzeige'
  },
  'inbox view template hoverHelp' => {
    'lastUpdated' => '1233553898',
    'message' => 'Die Vorlage zur Anzeige des Posteingangs.'
  },
  'inbox view template label' => {
    'lastUpdated' => '1233943261',
    'message' => 'Vorlage Eingangsanzeige'
  },
  'inbox_form_delete' => {
    'lastUpdated' => '1235680001',
    'message' => 'Eine Box zum Markieren von Mitteilungen, die gelöscht werden sollen.'
  },
  'invalid email' => {
    'lastUpdated' => '1245619596',
    'message' => '\'%s\' ist eine ungültige Emailadresse'
  },
  'invitation confirm label' => {
    'lastUpdated' => '1233555662',
    'message' => 'Versendete Einladungen'
  },
  'invitation confirm message' => {
    'lastUpdated' => '1232886103',
    'message' => 'Die folgenden Benutzer wurden benachrichtigt:'
  },
  'invitation confirm message template hoverHelp' => {
    'lastUpdated' => '1233555420',
    'message' => 'Die Vorlage zur Anzeige von Einladungsbestätigungen.'
  },
  'invitation confirm message template label' => {
    'lastUpdated' => '1233943145',
    'message' => 'Vorlage Einladungsbestätigungen'
  },
  'invitation count' => {
    'lastUpdated' => '1232885245',
    'message' => 'Einladungen'
  },
  'invitation does not exist' => {
    'lastUpdated' => '1232886209',
    'message' => 'Die Einladung, welche sie anzeigen lassen möchten, wurde bereits angenommen oder abgelehnt.'
  },
  'invitation label' => {
    'lastUpdated' => '1232886217',
    'message' => 'Einladung'
  },
  'invitation message' => {
    'lastUpdated' => '1232886254',
    'message' => '%s hat Sie eingeladen, seinem Kontaktnetzwerk beizutreten.'
  },
  'invitation sent label' => {
    'lastUpdated' => '1232886285',
    'message' => 'Einladung versendet'
  },
  'invitation sent text' => {
    'lastUpdated' => '1232886315',
    'message' => 'Ihre Einladung wurde erfolgreich versendet.'
  },
  'invitation_count' => {
    'lastUpdated' => '1232886350',
    'message' => 'Die Anzahl der Einladungen, welche der Benutzer empfangen hat.'
  },
  'invitations back label' => {
    'lastUpdated' => '1232886371',
    'message' => 'Zurück zu den Einladungen'
  },
  'invitations label' => {
    'lastUpdated' => '1232886377',
    'message' => 'Einladungen'
  },
  'invitations_enabled' => {
    'lastUpdated' => '1232886513',
    'message' => 'Diese Variable ist wahr, falls der Benutzer zugestimmt hat, Einladungen zu Kontaktnetzwerken zu empfangen.'
  },
  'invite a friend' => {
    'lastUpdated' => '1236437138',
    'message' => 'Laden Sie einen Bekannten ein'
  },
  'invite message' => {
    'lastUpdated' => '1233555575',
    'message' => 'Ich bin angemeldeter Benutzer auf einer Seite, die dich vielleicht interessieren könnte. Deshalb lasse ich dir diese Einladung zukommen. Folge dem Link, um dich zu registrieren!'
  },
  'invite subject' => {
    'lastUpdated' => '1232886649',
    'message' => 'Eine Einladung von %s'
  },
  'invite user confirm template hoverHelp' => {
    'lastUpdated' => '1232886723',
    'message' => 'Die Vorlage zur Anzeige von Einladungsbestätigungen.'
  },
  'invite user confirm template label' => {
    'lastUpdated' => '1233943229',
    'message' => 'Vorlage Einladungsbestätigungen'
  },
  'invite user enabled template hoverHelp' => {
    'lastUpdated' => '1233554829',
    'message' => 'Ermöglicht Benutzern Einladungen an Freunde zu verschicken mit der Aufforderung, ein Konto auf dieser Seite zu eröffnen. Damit diese Funktion Sinn macht, sollte zusätzlich die Möglichkeit zur anonymen Registrierung aktiviert werden.'
  },
  'invite user enabled template label' => {
    'lastUpdated' => '1232886781',
    'message' => 'Einladungen zulassen?'
  },
  'invite user message hoverHelp' => {
    'lastUpdated' => '1233555369',
    'message' => 'Der Vorgabetext für Einladungen. Das Feld erlaubt die Verwendung von Makros. In den von Benutzern erstellten Einladungen werden jedoch keine Makros mehr verarbeitet.'
  },
  'invite user message label' => {
    'lastUpdated' => '1232886935',
    'message' => 'Vorgabe Einladungstext'
  },
  'invite user message template hoverHelp' => {
    'lastUpdated' => '1233555896',
    'message' => 'Die Vorlage für Einladungs-Mails. Diese enthält sowohl den Nachrichtentext als auch den Registrierungslink sowie weitere Kopf- und Fußzeilen, die optional hinzugefügt werden können.'
  },
  'invite user message template label' => {
    'lastUpdated' => '1233943215',
    'message' => 'Vorlage Einladungs-Mails'
  },
  'invite user restrict message template hoverHelp' => {
    'lastUpdated' => '1233555187',
    'message' => 'Falls diese Einstellung aktiviert ist, dürfen Benutzer den Vorgabetext für Einladungen nicht verändern.'
  },
  'invite user restrict message template label' => {
    'lastUpdated' => '1232889238',
    'message' => 'Einladungstext veränderbar?'
  },
  'invite user restrict subject template hoverHelp' => {
    'lastUpdated' => '1233555236',
    'message' => 'Falls diese Einstellung aktiviert ist, dürfen Benutzer den vorgegebenen Betreff von Einladungen nicht verändern.'
  },
  'invite user restrict subject template label' => {
    'lastUpdated' => '1232889225',
    'message' => 'Einladungsbetreff veränderbar?'
  },
  'invite user subject template hoverHelp' => {
    'lastUpdated' => '1233555353',
    'message' => 'Die Vorgabe für den Betreff von Einladungen. Das Feld erlaubt die Verwendung von Makros. In den von Benutzern erstellten Einladungen werden jedoch keine Makros mehr verarbeitet.'
  },
  'invite user subject template label' => {
    'lastUpdated' => '1232886922',
    'message' => 'Vorgabe Einladungsbetreff'
  },
  'invite user template hoverHelp' => {
    'lastUpdated' => '1233555398',
    'message' => 'Die Vorlage zur Anzeige der Einladungsfunktion.'
  },
  'invite user template label' => {
    'lastUpdated' => '1233943195',
    'message' => 'Vorlage Einladungsfunktion'
  },
  'invite_friend_url' => {
    'lastUpdated' => '1232485553',
    'message' => 'Der URL, um diesen Benutzer als einen Freund in das eigene Kontaktnetzwerk aufzunehmen.'
  },
  'inviter no longer exists' => {
    'lastUpdated' => '1232485378',
    'message' => 'Der Benutzer, von dem diese Einladung stammt, ist nicht länger auf dieser Seite registriert.'
  },
  'isCompleted' => {
    'lastUpdated' => '1235680740',
    'message' => 'Eine Variable die wahr ist, falls diese Mitteilung eine Aktion des Benutzers darstellt, die abgeschlossen wurde.'
  },
  'isPending' => {
    'lastUpdated' => '1235681094',
    'message' => 'Eine Variable die wahr ist, falls diese Mitteilung eine Aktion des Benutzers darstellt, die sich noch in der Schwebe befindet.'
  },
  'isRead' => {
    'lastUpdated' => '1235681148',
    'message' => 'Eine Variable die wahr ist, falls diese Mitteilung bereits gelesen wurde.'
  },
  'isReplied' => {
    'lastUpdated' => '1235681175',
    'message' => 'Eine Variable die wahr ist, falls auf diese Mitteilung bereits geantwortet wurde.'
  },
  'mark as read label' => {
    'lastUpdated' => '1305396853',
    'message' => 'Als \'gelesen\' markieren.'
  },
  'mark as unread label' => {
    'lastUpdated' => '1305396879',
    'message' => 'Als \'ungelesen\' markieren'
  },
  'member since' => {
    'lastUpdated' => '1233944766',
    'message' => 'Registriert seit dem'
  },
  'message count' => {
    'lastUpdated' => '1232485233',
    'message' => 'Mitteilungen'
  },
  'message does not exist' => {
    'lastUpdated' => '1232485207',
    'message' => 'Die von Ihnen aufgerufene Mitteilung wurde bereits gelöscht.'
  },
  'message sent label' => {
    'lastUpdated' => '1232485134',
    'message' => 'Nachricht versendet'
  },
  'message sent text' => {
    'lastUpdated' => '1232485097',
    'message' => 'Ihre Nachricht wurde erfolgreich versendet.'
  },
  'message_id' => {
    'lastUpdated' => '1235680755',
    'message' => 'Der eindeutige Bezeichner für diese Nachricht.'
  },
  'message_loop' => {
    'lastUpdated' => '1235680913',
    'message' => 'Eine Schleife, die alle Mitteilungen der aktuellen Seite enthält; sortiert entsprechend den Vorgaben.'
  },
  'message_rpp' => {
    'lastUpdated' => '1235681444',
    'message' => 'Ein Auswahlfeld, dass es dem Benutzer gestattet, die Anzahl der pro Seite angezeigten Mitteilungen zu wählen.'
  },
  'message_total' => {
    'lastUpdated' => '1235680942',
    'message' => 'Die Gesamtzahl aller Mitteilungen, die der Benutzer in seinem Posteingang hat.'
  },
  'message_url' => {
    'lastUpdated' => '1235681200',
    'message' => 'Der URL zur Anzeige des Inhalts dieser Mitteilung.'
  },
  'messages label' => {
    'lastUpdated' => '1232485031',
    'message' => 'Mitteilungen'
  },
  'missing email' => {
    'lastUpdated' => '1232484916',
    'message' => 'Die Einladung kann nicht versendet werden, da Sie keine E-Mailadresse angegeben haben.'
  },
  'missing message' => {
    'lastUpdated' => '1232484875',
    'message' => 'Ihre Einladung benötigt einen Mitteilungstext.'
  },
  'missing subject' => {
    'lastUpdated' => '1232484831',
    'message' => 'Ihre Einladung benötigt eine Betreffzeile.'
  },
  'new message label' => {
    'lastUpdated' => '1232484795',
    'message' => 'Neue Mitteilung'
  },
  'new_message_url' => {
    'lastUpdated' => '1235680174',
    'message' => 'Der URL zur Ansicht, in der Benutzer neue Mitteilungen verfassen und an andere Benutzer senden können.'
  },
  'next label' => {
    'lastUpdated' => '1232484770',
    'message' => 'Nächste'
  },
  'no access' => {
    'lastUpdated' => '1232484573',
    'message' => 'Sie haben keine Berechtigung, diese Mitteilung zu lesen.'
  },
  'no access to invitation' => {
    'lastUpdated' => '1232484597',
    'message' => 'Sie haben keine Berechtigung, diese Einladung zu sehen.'
  },
  'no email' => {
    'lastUpdated' => '1232484471',
    'message' => 'Die Einladung kann nicht versendet werden, da Sie in Ihrem Profil keine E-Mailadresse angegeben haben.'
  },
  'no friends error' => {
    'lastUpdated' => '1232483769',
    'message' => 'Sie haben keine registrierten Freunde. Falls Sie private Mitteilungen an andere Benutzer versenden wollen ohne deren Profil aufzusuchen, müssen Sie diese erst als Freunde zu ihrem Profil hinzufügen.'
  },
  'no friends hover' => {
    'lastUpdated' => '1231218342',
    'message' => 'Sie müssen aktivierte Freunde im System haben um neue private Nachrichten ohne vorherige Profilbestimmung verschicken zu können.  '
  },
  'no invitations' => {
    'lastUpdated' => '1232484968',
    'message' => 'Sie haben keine ausstehenden Einladungen.'
  },
  'no messagable friends error' => {
    'lastUpdated' => '1245619636',
    'message' => 'Keine Ihrer Kontakte möchten privat kontaktiert werden.'
  },
  'no message error' => {
    'lastUpdated' => '1231217941',
    'message' => 'Sie haben keine Nachricht eingetragen'
  },
  'no reply error' => {
    'lastUpdated' => '1231217906',
    'message' => 'Sie dürfen diese Nachricht nicht beantworten'
  },
  'no self error' => {
    'lastUpdated' => '1231217870',
    'message' => 'Sie dürfen keine Nachricht an Ihre eigene Emailadresse senden'
  },
  'no subject error' => {
    'lastUpdated' => '1231217826',
    'message' => 'Sie haben keinen Betreff für diese Nachricht angegeben'
  },
  'no user error' => {
    'lastUpdated' => '1231217802',
    'message' => 'Sie haben keinen Empfänger für diese Nachricht angegeben'
  },
  'previous label' => {
    'lastUpdated' => '1231217775',
    'message' => 'Zurück'
  },
  'received label' => {
    'lastUpdated' => '1231217754',
    'message' => 'Empfangen'
  },
  'recipients label' => {
    'lastUpdated' => '1231217744',
    'message' => 'Empfänger hinzufügen'
  },
  'remove text' => {
    'lastUpdated' => '1231217728',
    'message' => 'Löschen'
  },
  'reply label' => {
    'lastUpdated' => '1231217717',
    'message' => 'Antworten'
  },
  'reply message label' => {
    'lastUpdated' => '1231217690',
    'message' => 'Antwort zur Nachricht'
  },
  'rpp_url' => {
    'lastUpdated' => '1235680300',
    'message' => 'Der aktuelle URL inklusive Sortierkriterium, Sortierreihenfolge und Filterregeln.'
  },
  'send inbox notifications only' => {
    'lastUpdated' => '1244063692',
    'message' => 'Nur Mitteilungen zur Posteingang verschicken.'
  },
  'send inbox notifications only help' => {
    'lastUpdated' => '1244063770',
    'message' => 'Sollte WebGUI nur Mitteilungen zum Posteingang anstelle der kompltten Nachricht verschicken?'
  },
  'send label' => {
    'lastUpdated' => '1231217662',
    'message' => 'Senden'
  },
  'send reject notice' => {
    'lastUpdated' => '1274268022',
    'message' => 'Freundschaftsanfrage zurückgewiesen'
  },
  'send reject notice help' => {
    'lastUpdated' => '1274970731',
    'message' => 'Wähle, ob nach Zurückweisung einer Freundschaftsanfrage eine Nachricht an den zurückgewiesenen Benutzer gesandt werden soll.'
  },
  'status' => {
    'lastUpdated' => '1235679181',
    'message' => 'Der internationalisierte Status dieser Mitteilung.'
  },
  'status label' => {
    'lastUpdated' => '1231217653',
    'message' => 'Status'
  },
  'status_class' => {
    'lastUpdated' => '1235679208',
    'message' => 'Der interne Status dieser Mitteilung.'
  },
  'status_url' => {
    'lastUpdated' => '1235679246',
    'message' => 'Der URL, um die Mitteilungen im Posteingang nach Status zu sortieren.'
  },
  'subject' => {
    'lastUpdated' => '1235679282',
    'message' => 'Der Betreff dieser Nachricht.'
  },
  'subject label' => {
    'lastUpdated' => '1231217645',
    'message' => 'Betreff'
  },
  'subject_url' => {
    'lastUpdated' => '1235679263',
    'message' => 'Der URL, um die Mitteilungen im Posteingang nach Betreff zu sortieren.'
  },
  'system message error' => {
    'lastUpdated' => '1231217632',
    'message' => 'Diese Nachricht wurde vom System verschickt. Sie können keine Antwort senden.'
  },
  'title' => {
    'lastUpdated' => '1232888859',
    'message' => 'Posteingang'
  },
  'to label' => {
    'lastUpdated' => '1231217504',
    'message' => 'An'
  },
  'unread_message_count' => {
    'lastUpdated' => '1232482821',
    'message' => 'Die Anzahl der ungelesenen Nachrichten im Posteingang.'
  },
  'update label' => {
    'lastUpdated' => '1231217494',
    'message' => 'Aktualisieren'
  },
  'userFilter' => {
    'lastUpdated' => '1244063841',
    'message' => 'Ein Formelement zur Filterung der Absender der Nachrichtenliste '
  },
  'user_invitations_enabled' => {
    'lastUpdated' => '1232483253',
    'message' => 'Diese Variable ist wahr, falls die Seite so konfiguriert wurde, dass Einladungen an Benutzer außerhalb der Seite versendet werden.'
  },
  'view inbox template' => {
    'lastUpdated' => '1235681943',
    'message' => 'Benutzerkonto, Posteingang'
  },
  'view my profile' => {
    'lastUpdated' => '1231217482',
    'message' => 'Mein Profil ansehen, sowie andere es sehen können.'
  },
  'view_inbox_url' => {
    'lastUpdated' => '1232483291',
    'message' => 'Der URL zur Ansicht des Posteingangs.'
  },
  'view_invitations_url' => {
    'lastUpdated' => '1232483401',
    'message' => 'Der URL zur Ansicht der Einladungsfunktion.'
  }
}
;

1;
